import {
  select,
  json,
  geoMercator,
  geoPath,
  zoom,
  event,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { feature } from 'topojson';
// height and width  of svg
const svg = select('svg');
const width = window.innerWidth;
const height = window.innerHeight;
// Heading of the map
const HeaderText = 'India Map';
svg
  .append('text')
  .attr('y', 50)
  .attr('x', 150)
  .text(HeaderText)
  .attr('class', 'Header');
// Name of projection used
const projection = geoMercator()
  .translate([-600, 585])
  .scale([700]);
const pathGen = geoPath(projection);
const colorScale = scaleOrdinal(schemeCategory10); //schemecategory10 method to fill colors
// linking to data from gistgithub
json(
  'https://gist.githubusercontent.com/saivinay143/c29290aa116b6c6706c6e9cc161ab95e/raw/5d8504405dc8304bfdf0635ba831b295cdaff1cb/india.topojson',
).then((data) => {
  // Parsing of data
  const india = feature(data, data.objects.india);
  // Constructing a map with features data
  svg
    .selectAll('path')
    .data(india.features)
    .enter()
    .append('path')
    .attr('class', 'country') // Created class of country
    .attr('fill', (d) => colorScale(d.interpolateRainbow))
    .attr('d', (d) => pathGen(d))
    .append('title')
    .text((d) => d.interpolateRainbow);
});
